==> baloo_4.13.3.orig.tar.xz: baloo-4.13.3/src/pim/search/note/notesearchstore.cpp <==
/*
 * This file is part of the KDE Baloo Project
 * Copyright (C) 2014 Laurent Montel <montel@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) version 3, or any
 * later version accepted by the membership of KDE e.V. (or its
 * successor approved by the membership of KDE e.V.), which shall
 * act as a proxy defined in Section 6 of version 3 of the license.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "notesearchstore.h"

#include <KStandardDirs>
#include <KDebug>

using namespace Baloo;

NoteSearchStore::NoteSearchStore(QObject* parent)
    : PIMSearchStore(parent)
{
    m_prefix.insert(QLatin1String("subject"), QLatin1String("SU"));
    m_prefix.insert(QLatin1String("collection"), QLatin1String("C"));
    m_prefix.insert(QLatin1String("body"), QLatin1String("BO"));

    setDbPath(findDatabase(QLatin1String("notes")));
}

QStringList NoteSearchStore::types()
{
    return QStringList() << QLatin1String("Akonadi") << QLatin1String("Note");
}

BALOO_EXPORT_SEARCHSTORE(Baloo::NoteSearchStore, "baloo_notesearchstore")

==> baloo-5.1.1.tar.xz: baloo-5.1.1/src/pim/search/note/notesearchstore.cpp <==
/*
 * This file is part of the KDE Baloo Project
 * Copyright (C) 2014 Laurent Montel <montel@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) version 3, or any
 * later version accepted by the membership of KDE e.V. (or its
 * successor approved by the membership of KDE e.V.), which shall
 * act as a proxy defined in Section 6 of version 3 of the license.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "notesearchstore.h"

#include <QDebug>

using namespace Baloo;

NoteSearchStore::NoteSearchStore(QObject* parent)
    : PIMSearchStore(parent)
{
    m_prefix.insert(QLatin1String("subject"), QLatin1String("SU"));
    m_prefix.insert(QLatin1String("collection"), QLatin1String("C"));
    m_prefix.insert(QLatin1String("body"), QLatin1String("BO"));

    setDbPath(findDatabase(QLatin1String("notes")));
}

QStringList NoteSearchStore::types()
{
    return QStringList() << QLatin1String("Akonadi") << QLatin1String("Note");
}
